% ****** atten.m ******
% 
% This function calculates attenuation-rate profiles using a conductivity
% model, acid and ss Cl concentrations, and temperature and density
% profiles.  It can return either the total attenuation rate and its
% uncertainty, or the attenuation rate separated into its different
% components (pure, acid and ss Cl).
% 
% Joe MacGregor
% last updated: 01/31/11

function varargout                                  = atten(thick, depth_inc, acid, sscl, temp, vol_frac, do_premelt, do_eutectic, return_type, uncert_acid, uncert_sscl)

switch return_type; % return conductivity outputs of varying detail
    case 'std';
        conduct                                     = imp2cond(acid, sscl, temp, vol_frac, do_premelt, do_eutectic);
    case 'uncert';
        [conduct, conduct_uncert]                   = imp2cond(acid, sscl, temp, vol_frac, do_premelt, do_eutectic, uncert_acid, uncert_sscl);
    case 'sep';
        [conduct_pure, conduct_acid, conduct_sscl]  = imp2cond(acid, sscl, temp, vol_frac, do_premelt, do_eutectic); 
end;

density_ice                                         = 0.917; % density of pure ice (g/cm^3)
permitt_freespace                                   = 8.854e-12; % permittivity of free space (F/m)
speed_light                                         = 2.998e8; % speed of light (m/s)
cond_atten_conv                                     = (1e4 * log10(exp(1))) ./ (sqrt(looyenga(vol_frac .* density_ice)) .* (permitt_freespace * speed_light)); % (dB/km*M)
                                                      % conversion between ice conductivity and attenuation rate based on
                                                      % equations 9 and 10 in macgregor et al. (2007), which approaches 0.912 at pure ice density

switch return_type;
    case 'std';
        atten_set                                   = cond_atten_conv .* conduct; % main attenuation rate set
        atten_rate                                  = sum(atten_set .* depth_inc) / thick; % depth-averaged attenuation rate in dB/km
    case 'uncert';
        atten_std                                   = cond_atten_conv .* conduct; % main attenuation rate set
        atten_rate                                  = sum(atten_std .* depth_inc) / thick; % depth-averaged attenuation rate in dB/km
        atten_min                                   = cond_atten_conv .* (conduct - conduct_uncert); % low value using uncertainty
        atten_rate_min                              = sum(atten_min .* depth_inc) / thick;
        atten_max                                   = cond_atten_conv .* (conduct + conduct_uncert); % high value using uncertainty
        atten_set                                   = [atten_std atten_min atten_max]; % attenuation rate profiles with low and high range
        atten_rate                                  = [atten_rate (atten_rate - atten_rate_min)]; % depth-averaged attenuation rate and uncertainty
    case 'sep';
        atten_pure                                  = cond_atten_conv .* conduct_pure; % pure ice attenuation rate set
        atten_rate_pure                             = sum(atten_pure .* depth_inc) / thick; % pure ice depth-averaged attenuation rate
        atten_acid                                  = cond_atten_conv .* conduct_acid;
        atten_rate_acid                             = sum(atten_acid .* depth_inc) / thick;
        atten_sscl                                  = cond_atten_conv .* conduct_sscl;
        atten_rate_sscl                             = sum(atten_sscl .* depth_inc) / thick;
        atten_set                                   = [atten_pure atten_acid atten_sscl];
        atten_rate                                  = [atten_rate_pure atten_rate_acid atten_rate_sscl];
end;

switch nargout; % return either just the depth-averaged values or the entire profiles
    case 1;
        varargout{1}                                = atten_rate;
    case 2;
        [varargout{1}, varargout{2}]                = deal(atten_rate, atten_set);
end;


% *** END OF FILE ***