% ****** dielec_props.m ******
% 
% This function calculates the means and uncertainties for the dielectric
% properties in the conductivity model.  See Table 1 in MacGregor et al. 
% (2007) for further details.  The "weighted" calculation method follows 
% Bevington (1969) and is not recommended, as per the reasons given in the paper.  
% All the dielectric properties have two names here, one abbreviated for
% the statistical calculation and the other complete, which is rounded to the 
% appropriate number of significant figures (2) and used in imp2cond.m to 
% calculate ice conductivity.
% 
% There are several model types: std, std_wt and jc75.  I prefer jc75,
% which uses the pure ice values from Johari and Charette (1975), since it
% has the best match at Siple Dome and those data are the most complete.
% 
% Joe MacGregor
% Last updated: 06/28/09

function dielec_props(model_type, all_cpure, do_usscl, do_save, do_disp)

conv_eV_J                           = 1.602e-19; % number of J in 1 eV

switch model_type;
    case 'std_wt';
        do_weight_all               = true;
    otherwise;
        do_weight_all               = false;
end;

if do_weight_all; % do weights based on uncertainties, can further modify for specific dielectric properties
    do_e_pure_weight                = true;
    do_e_acid_weight                = true;
    do_c_pure_weight                = true;
    do_u_acid_weight                = true;
else % don't do weights, which is the standard approach
    do_e_pure_weight                = false;
    do_e_acid_weight                = false;
    do_c_pure_weight                = false;
    do_u_acid_weight                = false;
end;

% reported values (1st row) and their uncertainties (2nd row)
e_pure                              = [0.61 0.51 0.585 0.51; 0 0.01 0.024 0.01];
e_acid                              = [0.195 0.26 0.20 0.16; 0 0.03 0.01 0];
e_sscl                              = [0.19; 0.02];
if all_cpure; % use all reported cpure values
    c_pure                          = [4.5 9.2 12.7 6.1 6.0 4.9; 0 0.2 0.3 0.6 0.1 1.0];
else % use only the non-dep cpure values, which is the standard approach
    c_pure                          = [4.5 9.2 6.0; 0 0.2 0.1];
end;
u_acid                              = [2.57 3.5 3.66 3.5 2.3 3.0 3.1 3.8; 0.09 0.3 0.16 0.5 1.0 0 0.7 0];
u_sscl                              = [0.43; 0.01];

if do_e_pure_weight;
    e_pure(~e_pure)                 = mean(e_pure(2, logical(e_pure(2, :))));
    mean_e_pure                     = sum(e_pure(1, :) ./ (e_pure(2, :) .^ 2)) / sum(1 ./ (e_pure(2, :) .^ 2));
    uncert_e_pure                   = sqrt(1 / sum(1 ./ (e_pure(2, :) .^ 2)));
else
    mean_e_pure                     = mean(e_pure(1, :));
    uncert_e_pure                   = std(e_pure(1, :));
end;

if do_e_acid_weight;
    e_acid(~e_acid)                 = mean(e_acid(2, logical(e_acid(2, :))));
    mean_e_acid                     = sum(e_acid(1, :) ./ (e_acid(2, :) .^ 2)) / sum(1 ./ (e_acid(2, :) .^ 2));
    uncert_e_acid                   = sqrt(1 / sum(1 ./ (e_acid(2, :) .^ 2)));
else
    mean_e_acid                     = mean(e_acid(1, :));
    uncert_e_acid                   = std(e_acid(1, :));
end;

mean_e_sscl                         = e_sscl(1);
uncert_e_sscl                       = e_sscl(2);

if do_c_pure_weight;
    c_pure(~c_pure)                 = mean(c_pure(2, logical(c_pure(2, :))));
    mean_c_pure                     = sum(c_pure(1, :) ./ (c_pure(2, :) .^ 2)) / sum(1 ./ (c_pure(2, :) .^ 2));
    uncert_c_pure                   = sqrt(1 / sum(1 ./ (c_pure(2, :) .^ 2)));
else
    mean_c_pure                     = mean(c_pure(1, :));
    uncert_c_pure                   = std(c_pure(1, :));
end;

if do_u_acid_weight;
    u_acid(~u_acid)                 = mean(u_acid(2, logical(u_acid(2, :))));
    mean_u_acid                     = sum(u_acid(1, :) ./ (u_acid(2, :) .^ 2)) / sum(1 ./ (u_acid(2, :) .^ 2));
    uncert_u_acid                   = sqrt(1 / sum(1 ./ (u_acid(2, :) .^ 2)));
else
    mean_u_acid                     = mean(u_acid(1, :));
    uncert_u_acid                   = std(u_acid(1, :));
end;

mean_u_sscl                         = mean(u_sscl(1, :));
% uncert_u_sscl                       = std(u_sscl(1, :));
uncert_u_sscl                       = u_sscl(2);

% getting everything ready for imp2cond world
activ_energy_pure                   = conv_eV_J * (round(100 * mean_e_pure) / 100);
activ_energy_acid                   = conv_eV_J * (round(100 * mean_e_acid) / 100);
activ_energy_sscl                   = conv_eV_J * (round(100 * mean_e_sscl) / 100);
cond_pure                           = 1e-6 * (round(10 * mean_c_pure) / 10);
molar_cond_acid                     = round(10 * mean_u_acid) / 10;
molar_cond_sscl                     = round(100 * mean_u_sscl) / 100;
uncert_activ_energy_pure            = conv_eV_J * (round(100 * uncert_e_pure) / 100);
uncert_activ_energy_acid            = conv_eV_J * (round(100 * uncert_e_acid) / 100);
uncert_activ_energy_sscl            = conv_eV_J * (round(100 * uncert_e_sscl) / 100);
uncert_cond_pure                    = 1e-6 * (round(10 * uncert_c_pure) / 10);
uncert_molar_cond_acid              = round(10 * uncert_u_acid) / 10;

if ~do_usscl;
    uncert_molar_cond_sscl          = round(100 * uncert_u_sscl) / 100;
else % reassigning molar_cond_sscl the same relative uncertainty as molar_cond_acid
    uncert_molar_cond_sscl          = round(100 * ((uncert_molar_cond_acid / molar_cond_acid) * molar_cond_sscl)) / 100; 
end;

switch model_type; % specifies a series of different conductivity models
    case 'jc75'; % uses johari and charette (1975) values for pure ice dielectric properties
        activ_energy_pure           = 0.51 * conv_eV_J;
        uncert_activ_energy_pure    = 0.01 * conv_eV_J;
        cond_pure                   = 9.2e-6;
        uncert_cond_pure            = 0.2e-6;
    case 'adj_epure'; % adjusted values are to match siple dome radar-derived and modeled attenuation rates
        activ_energy_pure           = 0.71 * conv_eV_J;
    case 'adj_eacid';
        activ_energy_acid           = 0.72 * conv_eV_J;
    case 'adj_esscl';
        activ_energy_sscl           = 0.87 * conv_eV_J;    
    case 'adj_cpure';
        cond_pure                   = 9.1e-6;
    case 'adj_uacid';
        activ_energy_pure           = 7.2;
    case 'adj_usscl';
        activ_energy_pure           = 1.56;
end;

if do_save; % save values in current path's data/ subdirectory for this version of the conductivity model
    save dielec_props activ* cond_pure molar*;
    save uncert_dielec_props uncert_activ* uncert_cond_pure uncert_molar*;
end;

if do_disp; % ouptut rounded values in command window
    disp(['E_pure = ' num2str(activ_energy_pure / conv_eV_J) ' +/- ' num2str(uncert_activ_energy_pure / conv_eV_J) ' eV']);
    disp(['E_acid = ' num2str(activ_energy_acid / conv_eV_J) ' +/- ' num2str(uncert_activ_energy_acid / conv_eV_J) ' eV']);
    disp(['E_sscl = ' num2str(activ_energy_sscl / conv_eV_J) ' +/- ' num2str(uncert_activ_energy_sscl / conv_eV_J) ' eV']);
    disp(['c_pure = ' num2str(1e6 * cond_pure) ' +/- ' num2str(1e6 * uncert_cond_pure) ' uS/m']);
    disp(['u_acid = ' num2str(molar_cond_acid) ' +/- ' num2str(uncert_molar_cond_acid) ' S/m/M']);
    disp(['u_sscl = ' num2str(molar_cond_sscl) ' +/- ' num2str(uncert_molar_cond_sscl) ' S/m/M']);
end;


% *** END OF FILE ***