% ****** imp2cond.m ******
% 
% This function calculates high-frequency ice conductivity based the
% conductivity model presented in MacGregor et al. (2007).  This model
% depends on temperature, density and the molar concentrations of acid and
% ss Cl.  It can also return the uncertainty in the conductivity and/or the
% separate conductivity contributions of each component in the model
% 
% do_premelt and do_eutectic are logical switches that turn on/off those adjustments.
% 
% vol_frac means "volume fraction", which is the ratio the density profile
% over the density of pure ice.
% 
% Joe MacGregor
% last updated: 06/28/09

function varargout  = imp2cond(acid, sscl, temp, vol_frac, do_premelt, do_eutectic, uncert_conc_acid, uncert_conc_sscl)

% arrhenius relationship constants
boltzmann                                       = 1.381e-23; % boltzmann constant
ref_temp                                        = 251; % reference temp
premelt_temp                                    = 263; % temperature at which pre-melting takes effect
eutectic_sscl                                   = 252; % eutectic point of sscl is -21 C

load dielec_props; % mean dielectric properties
if (nargin == 8); % then do uncertainty calculation
    load uncert_dielec_props; % dielectric property uncertainties
end;

% correct for pre-melting if doing that
if (do_premelt && any(temp >= premelt_temp));
    high_temps                                  = find(temp >= premelt_temp);
    premelt_fact                                = 2;
    molar_cond_acid                             = molar_cond_acid .* ones(size(temp));
    molar_cond_acid(high_temps)                 = molar_cond_acid(high_temps) .* ...
                                                  exp((activ_energy_acid / boltzmann) * ((1 / premelt_temp) - (1 / ref_temp)) * (premelt_fact - 1)); ...
                                                  % correct molar_cond_acid so that there is no discontinuity at premelt_temp
    activ_energy_acid                           = activ_energy_acid .* ones(size(temp));
    activ_energy_acid(high_temps)               = activ_energy_acid(high_temps) .* premelt_fact; % increases activ_energy_acid
    if (nargin == 8);
        uncert_activ_energy_acid                = uncert_activ_energy_acid .* ones(size(temp));
        uncert_activ_energy_acid(high_temps)    = uncert_activ_energy_acid(high_temps) .* premelt_fact; % increases activ_energy_acid
    end;
end;

conduct_pure                                    = cond_pure .* exp((activ_energy_pure / boltzmann) .* ((1 / ref_temp) - (1 ./ temp))); ...
                                                  % contribution from pure ice
conduct_acid                                    = (molar_cond_acid .* acid) .* exp((activ_energy_acid ./ boltzmann) .* ((1 / ref_temp) - (1 ./ temp))); ...
                                                  % contribution from acidic ice
conduct_sscl                                    = (molar_cond_sscl .* sscl) .* exp((activ_energy_sscl / boltzmann) * ((1 / ref_temp) - (1 ./ temp))); ...
                                                  % contribution froms salty ice

if (nargin == 8);
    % convenient terms from standard error propagation for each component of conductivity model
    exp_pure                                    = exp(((2 * activ_energy_pure) / boltzmann) .* ((1 / ref_temp) - (1 ./ temp)));
    exp_acid                                    = exp(((2 .* activ_energy_acid) ./ boltzmann) .* ((1 / ref_temp) - (1 ./ temp)));
    exp_sscl                                    = exp(((2 * activ_energy_sscl) / boltzmann) .* ((1 / ref_temp) - (1 ./ temp)));
    temp_k                                      = (((1 / ref_temp) - (1 ./ temp)) ./ boltzmann) .^ 2;
    % sum of each derivative from standard error propagation
    uncert_pure                                 = ((uncert_cond_pure ^ 2) .* exp_pure) + ...
                                                  (((uncert_activ_energy_pure * cond_pure) ^ 2) .* temp_k .* exp_pure);
    uncert_acid                                 = (((uncert_conc_acid * molar_cond_acid) .^ 2) .* exp_acid) + ...
                                                  (((uncert_molar_cond_acid .* acid) .^ 2) .* exp_acid) + ...
                                                  (((uncert_activ_energy_acid .* molar_cond_acid .* acid) .^ 2) .* temp_k .* exp_acid);
    uncert_sscl                                 = (((uncert_conc_sscl * molar_cond_sscl) ^ 2) .* exp_sscl) + ...
                                                  (((uncert_molar_cond_sscl .* sscl) .^ 2) .* exp_sscl) + ...
                                                  (((uncert_activ_energy_sscl .* molar_cond_sscl .* sscl) .^ 2) .* temp_k .* exp_sscl);
end;

% correct for eutectic of sscl if doing that and any temperatures are below sscl eutectic
if (do_eutectic && any(temp < eutectic_sscl));
    conduct_sscl(temp < eutectic_sscl)          = 0;
    if (nargin == 8);
        uncert_sscl(temp < eutectic_sscl)       = 0;
    end;
end;

if any(vol_frac ~= 1); % density corrections only if vol_frac implies they are necessary
    conduct_pure                                = conduct_pure .* vol_frac .* ((0.68 + (0.32 .* vol_frac)) .^ 2);
    conduct_acid                                = conduct_acid .* 1.21 .* ((vol_frac - 0.075) .^ 2.5);
    conduct_sscl                                = conduct_sscl .* vol_frac .* ((0.68 + (0.32 .* vol_frac)) .^ 2);
    if (nargin == 8);
        uncert_pure                             = uncert_pure .* vol_frac .* ((0.68 + (0.32 .* vol_frac)) .^ 2);
        uncert_acid                             = uncert_acid .* 1.21 .* ((vol_frac - 0.075) .^ 2.5);
        uncert_sscl                             = uncert_sscl .* vol_frac .* ((0.68 + (0.32 .* vol_frac)) .^ 2);
    end;
end;

conduct                                         = conduct_pure + conduct_acid + conduct_sscl; % total conductivity of impure ice
if (nargin == 8);
    conduct_uncert                              = sqrt(uncert_pure + uncert_acid + uncert_sscl); % total conductivity error
end;

switch nargout; % return conductivity components based on desired number of outputs
    case 1;
        varargout{1}                            = conduct;
    case 2;
        [varargout{1}, ...
            varargout{2}]                       = deal(conduct, conduct_uncert);
    case 3;
        [varargout{1}, ...
            varargout{2}, ...
            varargout{3}]                       = deal(conduct_pure, conduct_acid, conduct_sscl);
    case 4;
        [varargout{1}, ...
            varargout{2}, ...
            varargout{3}, ...
            varargout{4}]                       = deal(conduct, conduct_pure, conduct_acid, conduct_sscl);
    case 5;
        [varargout{1}, ...
            varargout{2}, ...
            varargout{3}, ...
            varargout{4}, ...
            varargout{5}]                       = deal(conduct, conduct_uncert, conduct_pure, conduct_acid, conduct_sscl);
    otherwise;
        varargout{1}                            = conduct;
end;


% *** END OF FILE ***