% ****** spole_atten.m ******
% 
% Attenuation-rate model for South Pole.
% 
% Joe MacGregor
% Last updated: 07/13/11

clear;

plotting                    = false;            % plotting switch
dielec_props('jc75', false, true, true, false); % set dielectric properties to jc75+std model

% depth vectors
thick                       = 2810;                                     % ice thickness (m)
depth                       = (0:10:thick)';                            % full depth vector (m)
depth_inc                   = diff(depth);                              % increments between depths (m)
depth_mid                   = depth(1:(end - 1)) + (depth_inc ./ 2);    % interval midpoint depths (one fewer than depth)
num_depth                   = length(depth_mid);                        % number of depth intervals

a                           = load('spole_temp');                       % load temperature data
[temp, depth_temp]          = deal((a.temp + 273.15), a.depth);         % reassign temperature data and get into K
temp_interp                 = zeros(num_depth, 1);                      % initialize interpolated temperature profile
ind_bot                     = nearest(depth_mid, depth_temp(end));      % nearest depth_mid index of bottom-most data point
% temperature profile from surface to bottom of data is approximately cubic
temp_interp(1:(ind_bot + 1)) ...
                            = polyval(polyfit(depth_temp, temp, 3), depth_mid(1:(ind_bot + 1)));
% temperature profile from bottom of data to bed is approximately linear
temp_interp((ind_bot + 2):end) ...
                            = interp1(depth_mid(1:(ind_bot + 1)), temp_interp(1:(ind_bot + 1)), depth_mid((ind_bot + 2):end), 'linear', 'extrap');
clear a;

% impurity concentrations in ice column
acid_mean                   = 1.7e-6;   % mean molar acid concentration (mol/L) from 2001 120-m core, measured by Cole-Dai et al.
sscl_mean                   = 0.6e-6;
acid_uncert                 = 0.5e-6;   % acid concentration uncertainty 
sscl_uncert                 = 0.5e-6;

density_ice                 = 0.917;                                                        % density of pure ice
a                           = load('spole_density');                                        % load density data
[density, depth_density]    = deal(a.density, a.depth);                                     % reassign density data
density_interp              = interp1([depth_density; thick], [density; 0.917], depth_mid); % interpolate to all depths
vol_frac                    = density_interp ./ density_ice;                                % volume fraction (density ratio relative to pure ice)
clear a;

% attenuation rates and uncertainty (dB/km)
[atten_rates, atten_sets]   = atten(thick, depth_inc, acid_mean, sscl_mean, temp_interp, vol_frac, false, false, 'uncert', acid_uncert , sscl_uncert);
 % attenuation rates separated into pure, acid and sscl components
[atten_rates_sep, atten_sets_sep] ...
                            = atten(thick, depth_inc, acid_mean, sscl_mean, temp_interp, vol_frac, false, false, 'sep');
atten_ave                   = cumsum(atten_sets(:, 1) .* depth_inc) ./ depth(2:end);    % depth_averaged attenuation rate to each depth (dB/km)
atten_tot                   = 2 .* cumsum(atten_sets(:, 1)) .* (depth_inc ./ 1e3);      % total attenuation to each depth (dB)

%%
if plotting;
%% temperature data and interpolation
    figure;
    hold on;
    plot((temp_interp - 273.15), depth_mid, 'k--', 'linewidth', 2);
    plot((temp - 273.15), depth_temp, 'b.', 'markersize', 24);
    set(gca, 'fontsize', 16);
    xlabel('Temperature ({\circ}C)');
    ylabel('Depth (m)');
    axis ij;
    ylim([0 thick]);
    grid on;
    box on;
%% attenuation rate models
    figure;
    subplot(131);
    hold on;
    tu = fill([atten_sets(:, 2); flipud(atten_sets(:, 3))], [depth_mid; flipud(depth_mid)], [0.8 0.8 0.8], 'edgecolor', 'none');
    p = plot(atten_sets_sep(:, 1), depth_mid, 'b', 'linewidth', 2);
    a = plot(atten_sets_sep(:, 2), depth_mid, 'r', 'linewidth', 2);
    s = plot(atten_sets_sep(:, 3), depth_mid, 'm', 'linewidth', 2);
    t = plot(atten_sets(:, 1), depth_mid, 'k', 'linewidth', 2);
    set(gca, 'fontsize', 16);
    xlabel({'One-way attenuation rate', '(dB/km)'});
    ylabel('Depth (m)');
    legend([p a s t tu], 'pure ice', 'acid', 'salt', 'total', 'uncertainty');
    axis ij;
    ylim([0 thick]);
    box on;
    grid on;
    subplot(132);
    plot(atten_ave, depth(2:end), 'k', 'linewidth', 2);
    set(gca, 'fontsize', 16);
    xlabel({'Depth-averaged one-way', 'attenuation rate (dB/km)'});
    axis ij;
    ylim([0 thick]);
    box on;
    grid on;
    subplot(133);
    plot(atten_tot, depth(2:end), 'k', 'linewidth', 2);
    set(gca, 'fontsize', 16);
    xlabel({'Total two-way', 'attenuation (dB)'});
    axis ij;
    ylim([0 thick]);
    box on;
    grid on;
%%    
end;


% *** END OF FILE ***